aboutsummaryrefslogtreecommitdiff
path: root/libstdc++-v3
diff options
context:
space:
mode:
authorGabriel Dos Reis <gdr@merlin.codesourcery.com>2001-05-30 11:34:26 +0000
committerGabriel Dos Reis <gdr@gcc.gnu.org>2001-05-30 11:34:26 +0000
commit3702c6346a575f2e2e1c9a6f3a8604b1dba1c5c6 (patch)
treefc2910508e52529de793d53be8556aa2f568e4a5 /libstdc++-v3
parente97c94888969b416c239fcaa027770d9b0157323 (diff)
downloadgcc-3702c6346a575f2e2e1c9a6f3a8604b1dba1c5c6.zip
gcc-3702c6346a575f2e2e1c9a6f3a8604b1dba1c5c6.tar.gz
gcc-3702c6346a575f2e2e1c9a6f3a8604b1dba1c5c6.tar.bz2
[multiple changes]
2001-05-29 Gabriel Dos Reis <gdr@merlin.codesourcery.com> * include/c_std/bits/std_cstdlib.h:: Move C99 thingies to __gnu_cxx::. * include/c_std/bits/std_cwchar.h (__gnu_cxx): Likewise. 2001-05-27 Gabriel Dos Reis <gdr@merlin.codesourcery.com> * include/c_std/bits/std_cmath.h: Move C99 functions in __gnu_cxx::. * include/c_std/bits/std_cstdlib.h: Same. * include/c_std/bits/std_cwchar.h: Same. From-SVN: r42707
Diffstat (limited to 'libstdc++-v3')
-rw-r--r--libstdc++-v3/ChangeLog11
-rw-r--r--libstdc++-v3/include/c_std/bits/std_cmath.h75
-rw-r--r--libstdc++-v3/include/c_std/bits/std_cstdlib.h22
-rw-r--r--libstdc++-v3/include/c_std/bits/std_cwchar.h8
4 files changed, 64 insertions, 52 deletions
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 837d60f..10f98d6 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,14 @@
+2001-05-29 Gabriel Dos Reis <gdr@merlin.codesourcery.com>
+
+ * include/c_std/bits/std_cstdlib.h:: Move C99 thingies to __gnu_cxx::.
+ * include/c_std/bits/std_cwchar.h (__gnu_cxx): Likewise.
+
+2001-05-27 Gabriel Dos Reis <gdr@merlin.codesourcery.com>
+
+ * include/c_std/bits/std_cmath.h: Move C99 functions in __gnu_cxx::.
+ * include/c_std/bits/std_cstdlib.h: Same.
+ * include/c_std/bits/std_cwchar.h: Same.
+
2001-05-30 Loren J. Rittle <ljrittle@acm.org>
* docs/html/17_intro/howto.html: Update link.
diff --git a/libstdc++-v3/include/c_std/bits/std_cstdlib.h b/libstdc++-v3/include/c_std/bits/std_cstdlib.h
index 50ef583..32475da 100644
--- a/libstdc++-v3/include/c_std/bits/std_cstdlib.h
+++ b/libstdc++-v3/include/c_std/bits/std_cstdlib.h
@@ -126,7 +126,7 @@ namespace std
} // namespace std
#if _GLIBCPP_USE_C99
-namespace c99
+namespace __gnu_cxx
{
using ::lldiv_t;
@@ -151,20 +151,20 @@ namespace c99
#ifdef _GLIBCPP_HAVE_STRTOLD
extern "C" long double strtold(const char*, char**);
#endif
-} // namespace c99
+} // namespace __gnu_cxx
namespace std
{
- using c99::lldiv_t;
- using c99::abs;
- //using c99::llabs; // XXX ???
- using c99::div;
- using c99::lldiv;
- using c99::atoll;
- using c99::strtoll;
- using c99::strtoull;
+ using __gnu_cxx::lldiv_t;
+ using __gnu_cxx::abs;
+ //using __gnu_cxx::llabs; // XXX ???
+ using __gnu_cxx::div;
+ using __gnu_cxx::lldiv;
+ using __gnu_cxx::atoll;
+ using __gnu_cxx::strtoll;
+ using __gnu_cxx::strtoull;
#ifdef _GLIBCPP_HAVE_STRTOLD
- using c99::strtold;
+ using __gnu_cxx::strtold;
#endif
}
#endif
diff --git a/libstdc++-v3/include/c_std/bits/std_cwchar.h b/libstdc++-v3/include/c_std/bits/std_cwchar.h
index d3fe012..b8f99ec 100644
--- a/libstdc++-v3/include/c_std/bits/std_cwchar.h
+++ b/libstdc++-v3/include/c_std/bits/std_cwchar.h
@@ -205,7 +205,7 @@ namespace std
}
#if _GLIBCPP_USE_C99
-namespace c99
+namespace __gnu_cxx
{
extern "C" long double wcstold(const wchar_t*, wchar_t**);
extern "C" long long int wcstoll(const wchar_t*, wchar_t**, int);
@@ -214,9 +214,9 @@ namespace c99
namespace std
{
- using c99::wcstold;
- using c99::wcstoll;
- using c99::wcstoull;
+ using __gnu_cxx::wcstold;
+ using __gnu_cxx::wcstoll;
+ using __gnu_cxx::wcstoull;
}
#endif
diff --git a/libstdc++-v3/include/c_std/bits/std_cmath.h b/libstdc++-v3/include/c_std/bits/std_cmath.h
index b6256d8..32a79d0 100644
--- a/libstdc++-v3/include/c_std/bits/std_cmath.h
+++ b/libstdc++-v3/include/c_std/bits/std_cmath.h
@@ -572,9 +572,9 @@ namespace std
#if _GLIBCPP_USE_C99
// These are possible macros imported from C99-land. For strict
-// conformance, remove possible C99-injected names from the
-// global namespace, and sequester them in the c99 namespace.
-namespace c99
+// conformance, remove possible C99-injected names from the global
+// namespace, and sequester them in the __gnu_cxx extension namespace.
+namespace __gnu_cxx
{
template<typename _Tp>
int
@@ -602,32 +602,33 @@ namespace c99
template<typename _Tp>
int
- __capture_isgreater(_Tp __f1, _Tp __f2) { return isgreater(__f1, __f2); }
+ __capture_isgreater(_Tp __f1, _Tp __f2)
+ { return isgreater(__f1, __f2); }
- template<typename _Tp>
- int
- __capture_isgreaterequal(_Tp __f1, _Tp __f2)
- { return isgreaterequal(__f1, __f2); }
+ template<typename _Tp>
+ int
+ __capture_isgreaterequal(_Tp __f1, _Tp __f2)
+ { return isgreaterequal(__f1, __f2); }
- template<typename _Tp>
- int
- __capture_isless(_Tp __f1, _Tp __f2) { return isless(__f1, __f2); }
+ template<typename _Tp>
+ int
+ __capture_isless(_Tp __f1, _Tp __f2) { return isless(__f1, __f2); }
- template<typename _Tp>
- int
- __capture_islessequal(_Tp __f1, _Tp __f2)
- { return islessequal(__f1, __f2); }
+ template<typename _Tp>
+ int
+ __capture_islessequal(_Tp __f1, _Tp __f2)
+ { return islessequal(__f1, __f2); }
- template<typename _Tp>
- int
- __capture_islessgreater(_Tp __f1, _Tp __f2)
- { return islessgreater(__f1, __f2); }
+ template<typename _Tp>
+ int
+ __capture_islessgreater(_Tp __f1, _Tp __f2)
+ { return islessgreater(__f1, __f2); }
- template<typename _Tp>
- int
- __capture_isunordered(_Tp __f1, _Tp __f2)
- { return isunordered(__f1, __f2); }
-} // namespace c99
+ template<typename _Tp>
+ int
+ __capture_isunordered(_Tp __f1, _Tp __f2)
+ { return isunordered(__f1, __f2); }
+} // namespace __gnu_cxx
#endif
#undef fpclassify
@@ -644,7 +645,7 @@ namespace c99
#undef isunordered
#if _GLIBCPP_USE_C99
-namespace c99
+namespace __gnu_cxx
{
template<typename _Tp>
int
@@ -701,18 +702,18 @@ namespace c99
namespace std
{
- using c99::fpclassify;
- using c99::isfinite;
- using c99::isinf;
- using c99::isnan;
- using c99::isnormal;
- using c99::signbit;
- using c99::isgreater;
- using c99::isgreaterequal;
- using c99::isless;
- using c99::islessequal;
- using c99::islessgreater;
- using c99::isunordered;
+ using __gnu_cxx::fpclassify;
+ using __gnu_cxx::isfinite;
+ using __gnu_cxx::isinf;
+ using __gnu_cxx::isnan;
+ using __gnu_cxx::isnormal;
+ using __gnu_cxx::signbit;
+ using __gnu_cxx::isgreater;
+ using __gnu_cxx::isgreaterequal;
+ using __gnu_cxx::isless;
+ using __gnu_cxx::islessequal;
+ using __gnu_cxx::islessgreater;
+ using __gnu_cxx::isunordered;
}
#endif